@@ -1,7 +1,7 @@
 package App::lcpan::Cmd::authors_by_rdep_count;
 
 our $DATE = '2016-10-14'; # DATE
-our $VERSION = '1.010'; # VERSION
+our $VERSION = '1.011'; # VERSION
 
 use 5.010;
 use strict;
@@ -50,7 +50,7 @@ sub handle_cmd {
     my $sql = "SELECT
   m.cpanid id,
   a.fullname name,
-  COUNT(*) AS rdep_count
+  COUNT(DISTINCT d.id) AS rdep_count
 FROM module m
 JOIN dep dp ON dp.module_id=m.id
 LEFT JOIN author a ON a.cpanid=m.cpanid
@@ -86,7 +86,7 @@ App::lcpan::Cmd::authors_by_rdep_count - List authors ranked by number of distri
 
 =head1 VERSION
 
-This document describes version 1.010 of App::lcpan::Cmd::authors_by_rdep_count (from Perl distribution App-lcpan), released on 2016-10-14.
+This document describes version 1.011 of App::lcpan::Cmd::authors_by_rdep_count (from Perl distribution App-lcpan), released on 2016-10-14.
 
 =head1 FUNCTIONS
 
